# Numpy 1.19.4 for Raspberry Pi and Python 3

## A version of numpy that is compatible with DL packages on Raspberry such as PyTorch, Tensorflow, and Keras

## Original is located here:
## https://github.com/numpy/numpy
